# emaremes

Convenience tools for reading and processing MRMS data.

https://github.com/user-attachments/assets/56616688-86d4-46a5-9fc9-e23e58149e65


**Installation**

```sh
pip install emaremes
```

**Documentation**

[https://edsaac.github.io/emaremes/](https://edsaac.github.io/emaremes/)


